Documentation
¶
Overview ¶
Package maskpass masks the password of an URL, so something like https://user:password@host:port/ would end up like https://user:xxxxxx@host:port/.
Usage:
The easiest way to use maskpass is with the method String.
uri := url.Parse("whatever")
masked := maskpass.String(uri.String())
Index ¶
Constants ¶
const MASK = "xxxxxx"
Variables ¶
This section is empty.
Functions ¶
func String ¶
String returns a masked url.URL.String() without error handling. It's a wrapper of String().
func StringError ¶
StringError returns the url.URL.String() value and an error if something went wrong calling Mask.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.